@@ -84,6 +84,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             use checkout_core::schemars::JsonSchema;
             use checkout_core::dropshot;
             use checkout_core::serde::{Serialize, Deserialize};
+            use checkout_core::serde_json;
             use checkout_core::dropshot::endpoint;
             use checkout_core::dropshot::RequestContext;
             use checkout_core::dropshot::Path;
@@ -133,7 +134,11 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             impl cloud_pubsub::FromPubSubMessage for Message {
                 fn from(message: cloud_pubsub::EncodedMessage) -> Result<Self, cloud_pubsub::error::Error> {
                     match message.decode() {
-                        Ok(bytes) => Ok(Message(String::from_utf8_lossy(&bytes).into_owned())),
+                        Ok(bytes) => {
+                            let raw_string = String::from_utf8_lossy(&bytes).into_owned();
+                            let val: serde_json::Value = serde_json::from_str(&raw_string).unwrap();
+                            Ok(Message(val.as_str().unwrap().to_string()))
+                        },
                         Err(e) => Err(cloud_pubsub::error::Error::from(e)),
                     }
                 }
@@ -160,7 +165,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                                                     if !ctx.start_transaction().await.is_ok() {
                                                         continue;
                                                     }
-                                                    let processing_result = process_handler(&internal_ctx, &mut ctx, message.0.as_str().unwrap()).await;
+                                                    let processing_result = process_handler(&mut ctx, &message.0).await;
                                                     if !processing_result.is_ok() {
                                                         if !ctx.abort_transaction().await.is_ok() {
                                                             // just log the failure to abort tx
